EVENT_LIST = {
    "on_bulk_message_delete": ["messages"],
    "on_connect": [],
    "on_disconnect": [],
    "on_error": ["event", " *args", " **kwargs"],
    "on_group_join": ["channel", " user"],
    "on_guild_available": ["guild"],
    "on_guild_channel_delete": ["channel"],
    "on_guild_channel_pins_update": ["channel", " last_pin"],
    "on_guild_channel_update": ["before", " after"],
    "on_guild_emojis_update": ["guild", " before", " after"],
    "on_guild_integrations_update": ["guild"],
    "on_guild_join": ["guild"],
    "on_guild_remove": ["guild"],
    "on_guild_role_create": ["role"],
    "on_guild_role_update": ["before", " after"],
    "on_guild_update": ["before", " after"],
    "on_invite_create": ["invite"],
    "on_invite_delete": ["invite"],
    "on_member_ban": ["guild", " user"],
    "on_member_join": ["member"],
    "on_member_unban": ["guild", " user"],
    "on_member_update": ["before", " after"],
    "on_message": ["message"],
    "on_message_delete": ["message"],
    "on_message_edit": ["before", " after"],
    "on_private_channel_delete": ["channel"],
    "on_private_channel_pins_update": ["channel", " last_pin"],
    "on_private_channel_update": ["before", " after"],
    "on_raw_bulk_message_delete": ["payload"],
    "on_raw_message_delete": ["payload"],
    "on_raw_message_edit": ["payload"],
    "on_raw_reaction_add": ["payload"],
    "on_raw_reaction_clear": ["payload"],
    "on_raw_reaction_clear_emoji": ["payload"],
    "on_raw_reaction_remove": ["payload"],
    "on_reaction_add": ["reaction", " user"],
    "on_reaction_clear": ["message", " reactions"],
    "on_reaction_clear_emoji": ["reaction"],
    "on_reaction_remove": ["reaction", " user"],
    "on_ready": [],
    "on_relationship_add": ["relationship"],
    "on_relationship_update": ["before", " after"],
    "on_resumed": [],
    "on_shard_connect": ["shard_id"],
    "on_shard_disconnect": ["shard_id"],
    "on_shard_ready": ["shard_id"],
    "on_shard_resumed": ["shard_id"],
    "on_socket_raw_receive": ["msg"],
    "on_socket_raw_send": ["payload"],
    "on_typing": ["channel", " user", " when"],
    "on_user_update": ["before", " after"],
    "on_voice_state_update": ["member", " before", " after"],
    "on_webhooks_update": ["channel"],
}
