# now I know this is probably not the right way but I don't know any other way to do this
SHORTHANDS = {
    "ctx.channel.send": "ctx.send",
    "ctx.author.guild": "ctx.guild",
    "ctx.message.author": "ctx.author",
    "ctx.message.author.guild": "ctx.author",
    "ctx.message.guild": "ctx.guild",
    "ctx.message.channel":"ctx.channel",
    "ctx.message.channel.guild":"ctx.guild",
    "ctx.channel.pins":"ctx.pins"
}